=======================
Timelink Python package
=======================

.. image:: https://img.shields.io/pypi/v/timelink.svg
        :target: https://pypi.python.org/pypi/timelink

.. image:: https://api.travis-ci.com/time-link/timelink-py.svg?branch=main
        :target: https://travis-ci.com/joaquimrcarvalho/timelink

.. image:: https://readthedocs.org/projects/timelink-py/badge/?version=latest
        :target: https://timelink-py.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status

* Free software: MIT license
* Documentation: https://timelink-py.readthedocs.io/
* PiPY: https://pypi.org/project/timelink/

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   readme
   installation
   usage
   documentation
   modules
   contributing
   authors
   history


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Credits
=======

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

